@@ -1,5 +1,6 @@
 import sys, os
 
+from AccessControl import ClassSecurityInfo
 from Acquisition import aq_base, aq_inner
 
 from zope.interface import implements
@@ -23,6 +24,13 @@ class CustomFolderExport(BrowserView):
 
     implements(ICustomFolderExport)
 
+    def __call__(self):
+        action = self.request.form.get('action')
+        if action is not None:
+            path = self.request.form.get('path')
+            return self.export(path=path)
+        return self.index()
+
     def export(self, path, customfolder=None):
         """ @see: ICustomFolderExport#export """
 
